@@ -1,4 +1,5 @@
-from collections.abc import Collection
+import logging
+from collections.abc import Collection, Mapping
 from http import HTTPStatus
 from logging import Logger, getLogger
 from time import time
@@ -12,7 +13,7 @@ from starlette.types import ASGIApp
 
 from py_fastapi_logging.config.config import init_logger
 from py_fastapi_logging.constants import REQUEST_ID_HEADER
-from py_fastapi_logging.middlewares.data_filter import DataFilter
+from py_fastapi_logging.data_filter import DataFilter
 from py_fastapi_logging.middlewares.utils.request_id import generate_request_id
 from py_fastapi_logging.schemas.request import RequestPayload
 from py_fastapi_logging.schemas.response import ResponsePayload
@@ -104,7 +105,7 @@ class LoggingMiddleware(BaseHTTPMiddleware):
                 host=f"{host_or_socket}:{port}" if port is not None else host_or_socket,
                 body=request_body,
             )
-            self._data_filter.filter_request_payload(request_log_payload, request.headers)
+            self._filter_request_payload(request_log_payload, request.headers)
             extra_payload: dict[str, Any] = common_extras | {
                 "tags": ["API", "REQUEST"],
                 "payload": request_log_payload,
@@ -144,7 +145,7 @@ class LoggingMiddleware(BaseHTTPMiddleware):
                 "response_time": f"{duration}ms",
                 "response_body": response_body.decode(),
             }
-            self._data_filter.filter_response_payload(response_log_payload)
+            self._filter_response_payload(response_log_payload)
             extra_payload = common_extras | {
                 "tags": ["API", "RESPONSE"],
                 "payload": response_log_payload,
@@ -155,3 +156,16 @@ class LoggingMiddleware(BaseHTTPMiddleware):
 
     def _is_url_path_in_exclude_list(self, request: Request) -> bool:
         return any(request.url.path.startswith(path) for path in self._exclude_requests_starting_with)
+
+    def _filter_request_payload(self, payload: RequestPayload, headers: Mapping) -> None:
+        try:
+            payload["params"] = self._data_filter.filter_data(payload["params"])
+            payload["body"] = self._data_filter.filter_request_body(payload["body"], headers)
+        except Exception:
+            logging.exception("Failed to filter response payload")
+
+    def _filter_response_payload(self, payload: ResponsePayload) -> None:
+        try:
+            payload["response_body"] = self._data_filter.filter_json_body(payload["response_body"])
+        except Exception:
+            logging.exception("Failed to filter request payload")
